==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/sv.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated Delning",
    "Invalid Federated Cloud ID" : "Ogiltig Federerad Cloud-ID",
    "Sharing %s failed, because this item is already shared with %s" : "Delning %s misslyckades därför att objektet redan är delat med %s",
    "Not allowed to create a federated share with the same user" : "Ej tillåtet att skapa en federerad delning med samma användare",
    "File is already shared with %s" : "Filen är redan delad med %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Misslyckades dela ut %s, kan inte hitta %s, kanske är servern inte åtkomlig för närvarande.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du tog emot \"/%3$s\" som en fjärrdelning från %1$s (via %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Du tog emot \"/%3$s\" som en fjärrdelning från %1$s",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Dela med mig genom min #owncloud Federated Cloud ID, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Dela med mig genom min #ownCloud Federated Cloud ID",
    "Federated Cloud Sharing" : "Federate Cloud delning",
    "Open documentation" : "Öppna dokumentation",
    "Allow users on this server to send shares to other servers" : "Tillåt användare på denna server att skicka utdelningar till andra servrar",
    "Allow users on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot utdelningar från andra servrar",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Ditt Federated Cloud ID",
    "Share it:" : "Dela detta:",
    "Add to your website" : "Lägg till på din hemsida",
    "Share with me via ownCloud" : "Dela med mig via Owncloud",
    "HTML Code:" : "HTML Kod:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/sv.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated Delning",
    "Invalid Federated Cloud ID" : "Ogiltig Federerad Cloud-ID",
    "Sharing %s failed, because this item is already shared with %s" : "Delning %s misslyckades därför att objektet redan är delat med %s",
    "Not allowed to create a federated share with the same user" : "Ej tillåtet att skapa en federerad delning med samma användare",
    "File is already shared with %s" : "Filen är redan delad med %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Misslyckades dela ut %s, kan inte hitta %s, kanske är servern inte åtkomlig för närvarande.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du tog emot \"/%3$s\" som en fjärrdelning från %1$s (via %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Du tog emot \"/%3$s\" som en fjärrdelning från %1$s",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Dela med mig genom min #owncloud Federated Cloud ID, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Dela med mig genom min #ownCloud Federated Cloud ID",
    "Federated Cloud Sharing" : "Federate Cloud delning",
    "Open documentation" : "Öppna dokumentation",
    "Allow users on this server to send shares to other servers" : "Tillåt användare på denna server att skicka utdelningar till andra servrar",
    "Allow users on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot utdelningar från andra servrar",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Ditt Federated Cloud ID",
    "Share it:" : "Dela detta:",
    "Add to your website" : "Lägg till på din hemsida",
    "Share with me via ownCloud" : "Dela med mig via Owncloud",
    "HTML Code:" : "HTML Kod:",
    "Add to your ownCloud" : "Lägg till i din ownCloud"
},
"nplurals=2; plural=(n != 1);");
